pub fn worker_service(
state: ServerState,
) -> WorkerProtocolServer<WorkerGrpcService>Expand description
Construct the generated tonic server wrapper for the worker protocol.
pub fn worker_service(
state: ServerState,
) -> WorkerProtocolServer<WorkerGrpcService>Construct the generated tonic server wrapper for the worker protocol.