load_required

Function load_required 

pub fn load_required(path: &Path) -> Result<ServerConfig, ServerError>
Load and validate a required TOML config file.

Errors

Returns ServerError::Config when the file is missing, unreadable, unparsable, invalid, or Aion home cannot be resolved for omitted path defaults.