TerminationSignal

Enum TerminationSignal 

pub enum TerminationSignal {
    Sent,
    AlreadyGone,
}
What sending the termination signal to a verified incarnation did.

Variants



Sent

SIGTERM was delivered to the verified incarnation.



AlreadyGone

The process exited between the incarnation probe and the signal, so there was nobody to signal. The goal state already holds.