pub fn capability_opens() -> u64Expand description
The process-wide count of opens the server issues through its held
directory capabilities — the instrument behind the boot-cost pin (a boot
over a million object files must not open a million files).
How many opens this module has issued through held capabilities since
process start or the last reset_capability_opens.