SubscriptionScope

Enum SubscriptionScope 

pub enum SubscriptionScope<'a> {
    PerWorkflow(&'a PerWorkflowSubscription, WorkflowTarget<'a>),
    Filtered(&'a FilteredSubscription),
    Firehose(&'a FirehoseSubscription),
}
Event subscription namespace scope decoded by a stream adapter.

Variants



PerWorkflow(&'a PerWorkflowSubscription, WorkflowTarget<'a>)

Events for one workflow.



Filtered(&'a FilteredSubscription)

Filtered events in the caller namespace.



Firehose(&'a FirehoseSubscription)

Firehose events in the caller namespace.

Implementations

Source

impl<'a> SubscriptionScope<'a>

pub fn from_request( request: &'a SubscriptionRequest, workflow_target: Option<WorkflowTarget<'a>>, ) -> Result<Self, ServerError>

Decode the namespace scope from a subscription request after the handler has decoded any workflow identifiers required by the selected variant.

Errors

Returns ServerError::Namespace when the request omits the subscription variant.