pub struct WorkflowTarget<'a> { /* private fields */ }Expand description
Target workflow identifiers decoded by a handler before the engine call.
Implementations
Sourceimpl<'a> WorkflowTarget<'a>
impl<'a> WorkflowTarget<'a>
Sourcepub const fn with_run(workflow_id: &'a WorkflowId, run_id: &'a RunId) -> Self
pub const fn with_run(workflow_id: &'a WorkflowId, run_id: &'a RunId) -> Self
Build a target for operations that require workflow and run identifiers.
Sourcepub const fn workflow(workflow_id: &'a WorkflowId) -> Self
pub const fn workflow(workflow_id: &'a WorkflowId) -> Self
Build a target for operations that identify only a workflow.
Sourcepub const fn workflow_id(&self) -> &WorkflowId
pub const fn workflow_id(&self) -> &WorkflowId
Target workflow id.