pub enum MetricsError {
Register(Error),
Encode(String),
}Expand description
Prometheus registry construction or exposition error.
Variants
Register(Error)
A metric failed to register in the prometheus registry.
Encode(String)
The prometheus text encoder failed to encode gathered metric families.