pub fn current_hops(metadata: &MetadataMap) -> u32Expand description
Read the current hop count from request metadata (0 when absent/malformed).
pub fn current_hops(metadata: &MetadataMap) -> u32Read the current hop count from request metadata (0 when absent/malformed).