pub struct ObservedMiss {
pub reason: QueueServiceReason,
pub census: PoolCensus,
}Expand description
What one classified selection miss turned out to be.
Fields
reason: QueueServiceReasonThe classified reason this address is not being served.
census: PoolCensusThe live poller census the classification was made against.