pub struct CliOverrides {
pub config_path: Option<PathBuf>,
pub listen_address: Option<SocketAddr>,
pub store_url: Option<String>,
pub scheduler_threads: Option<usize>,
pub drain_timeout_seconds: Option<u64>,
pub workflow_packages: Vec<PathBuf>,
}Expand description
Command-line configuration overrides applied after file and environment values.
Fields
config_path: Option<PathBuf>Optional explicit config path from --config.
listen_address: Option<SocketAddr>Override for [server].listen_address.
store_url: Option<String>Override for [store].url.
scheduler_threads: Option<usize>Override for [runtime].scheduler_threads.
drain_timeout_seconds: Option<u64>Override for [drain].timeout_seconds.
workflow_packages: Vec<PathBuf>Additional workflow package archives loaded after config and auto-discovered packages.