ActivityCompletionSink

Trait ActivityCompletionSink 

pub trait ActivityCompletionSink {
    // Required method
    fn complete_activity(
        &self,
        completion: ActivityCompletion,
    ) -> Result<(), ServerError>;
}
Engine-owned activity completion contract used by the worker endpoint.

Required Methods

fn complete_activity( &self, completion: ActivityCompletion, ) -> Result<(), ServerError>

Feed one worker-reported result into the engine activity contract.

Errors

Returns ServerError when the engine rejects or cannot record the completion.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors