pub struct AttemptKey {
pub workflow_id: WorkflowId,
pub activity_id: ActivityId,
pub attempt: u32,
}Expand description
The (workflow, activity, attempt) key one running agent session is addressed
by — the same identity the worker back-index and the whole design key on.
Fields
workflow_id: WorkflowIdThe workflow the target activity belongs to.
activity_id: ActivityIdThe target activity within the workflow.
attempt: u32The target attempt. A command to any other attempt is a stale-target no-op.
Implementations
Sourceimpl AttemptKey
impl AttemptKey
Sourcepub const fn new(
workflow_id: WorkflowId,
activity_id: ActivityId,
attempt: u32,
) -> Self
pub const fn new( workflow_id: WorkflowId, activity_id: ActivityId, attempt: u32, ) -> Self
Build an attempt key from its three components.
Sourcepub fn of_command(command: &InterventionCommand) -> Self
pub fn of_command(command: &InterventionCommand) -> Self
The attempt key naming the target of a routed command.